import { NextRequest, NextResponse } from 'next/server';

declare type AuthCredentialsObject = {
    name: string;
    password: string;
};
declare type AuthCredentials = AuthCredentialsObject[];

type MiddlewareOptions = {
  pathname?: string
  users?: AuthCredentials
  message?: string
  realm?: string
}

/**
 * Creates a default Next middleware function that returns `NextResponse.next()` if the basic auth passes
 * @param req Next middleware request
 * @param options Options object based on MiddlewareOptions
 * @returns Either a 401 error or goes to the next page
 */
declare const createNextAuthMiddleware: ({ pathname, users, message, realm, }?: MiddlewareOptions) => (req: NextRequest) => NextResponse;
declare const nextBasicAuthMiddleware: ({ pathname, users, message, realm, }: MiddlewareOptions | undefined, req: NextRequest) => NextResponse;

export { MiddlewareOptions, createNextAuthMiddleware, nextBasicAuthMiddleware };
